aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGravatar Tom Willemse2019-02-26 00:58:23 -0800
committerGravatar Tom Willemse2019-02-26 00:58:23 -0800
commitebb18729f21416fb55e6debb6360f18d216c7dcb (patch)
tree877a19c4d1535942beb65abfa834b5a6e284c67c
parentf313ba9c6aa869b2f615a23b97fd2c91024236e3 (diff)
downloademacs-config-ebb18729f21416fb55e6debb6360f18d216c7dcb.tar.gz
emacs-config-ebb18729f21416fb55e6debb6360f18d216c7dcb.zip
Add oni-common-lisp, delete oni-lisp-mode
-rw-r--r--oni-common-lisp.el (renamed from oni-lisp-mode.el)24
1 files changed, 17 insertions, 7 deletions
diff --git a/oni-lisp-mode.el b/oni-common-lisp.el
index 8f3df19..2430635 100644
--- a/oni-lisp-mode.el
+++ b/oni-common-lisp.el
@@ -1,11 +1,11 @@
-;;; oni-lisp-mode.el --- Lisp-mode configuration -*- lexical-binding: t; -*-
+;;; oni-common-lisp.el --- Common Lisp configuration -*- lexical-binding: t; -*-
;; Copyright (C) 2017 Tom Willemse
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 20190213225457
-;; Package-Requires: (oni-company oni-flycheck paredit rainbow-delimiters)
+;; Version: 20190226005649
+;; Package-Requires: (oni-company oni-flycheck paredit rainbow-delimiters slime slime-company)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
;;; Commentary:
;; Configuration for `lisp-mode'. Enables the following minor modes:
;; - `company-mode': For auto-completion.
;; - `flycheck-mode': For syntax checking.
@@ -31,12 +31,22 @@
;;; Code:
+(require 'slime)
+
+(setq slime-lisp-implementations
+ '((sbcl ("sbcl" "--noinform") :coding-system utf-8-unix)
+ (clisp ("clisp") :coding-system utf-8-unix)))
+
+(setq slime-default-lisp 'sbcl)
+
+(slime-setup '(slime-fancy slime-company))
+
(add-hook 'lisp-mode-hook 'paredit-mode)
(add-hook 'lisp-mode-hook 'rainbow-delimiters-mode)
(add-hook 'lisp-mode-hook 'flycheck-mode)
(add-hook 'lisp-mode-hook 'company-mode)
-;;;###autoload (with-eval-after-load 'lisp-mode (require 'oni-lisp-mode))
+;;;###autoload (with-eval-after-load 'lisp-mode (require 'oni-common-lisp))
-(provide 'oni-lisp-mode)
-;;; oni-lisp-mode.el ends here
+(provide 'oni-common-lisp)
+;;; oni-common-lisp.el ends here
@@ -22,7 +22,7 @@
;;; Commentary:
-;; Configuration for `lisp-mode'. Enables the following minor modes:
+;; Configuration for Common Lisp programming. Enables the following minor modes:
;; - `company-mode': For auto-completion.
;; - `flycheck-mode': For syntax checking.